@@ -1,9 +1,9 @@
 package Data::Sah::Coerce::perl::To_array::From_str::comma_sep;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-21'; # DATE
+our $DATE = '2021-04-08'; # DATE
 our $DIST = 'Data-Sah-CoerceBundle-To_array-From_str-comma_sep'; # DIST
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use 5.010001;
 use strict;
@@ -55,7 +55,7 @@ Data::Sah::Coerce::perl::To_array::From_str::comma_sep - Coerce array from a com
 
 =head1 VERSION
 
-This document describes version 0.012 of Data::Sah::Coerce::perl::To_array::From_str::comma_sep (from Perl distribution Data-Sah-CoerceBundle-To_array-From_str-comma_sep), released on 2020-05-21.
+This document describes version 0.013 of Data::Sah::Coerce::perl::To_array::From_str::comma_sep (from Perl distribution Data-Sah-CoerceBundle-To_array-From_str-comma_sep), released on 2021-04-08.
 
 =head1 SYNOPSIS
 
@@ -75,19 +75,26 @@ Source repository is at L<https://github.com/perlancar/perl-Data-Sah-CoerceBundl
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Sah-CoerceBundle-To_array-From_str-comma_sep>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Data-Sah-CoerceBundle-To_array-From_str-comma_sep/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Data::Sah::Coerce::perl::To_array::From_str::csv_row> can accomplish the same
+thing, with additional ability to handle escapes and quotes.
+
+L<Data::Sah::Coerce::perl::To_array::From_str::tsv_row>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
